@@ -31,7 +31,7 @@ class X11EventsPlugin : public EventsPlugin
     Q_OBJECT
 public:
     X11EventsPlugin(QObject *parent, const QVariantList &args);
-    virtual ~X11EventsPlugin() = default;
+    ~X11EventsPlugin() override = default;
 
     EventHandler *eventHandler() override;
 
