@@ -33,7 +33,7 @@ class XdpEventsPlugin : public EventsPlugin
     Q_OBJECT
 public:
     XdpEventsPlugin(QObject *parent, const QVariantList &args);
-    virtual ~XdpEventsPlugin() = default;
+    ~XdpEventsPlugin() override = default;
 
     EventHandler *eventHandler() override;
 
