@@ -35,7 +35,7 @@ public:
    PWFrameBufferPlugin(QObject *parent, const QVariantList &args);
    virtual ~PWFrameBufferPlugin() override;
 
-   FrameBuffer *frameBuffer(WId id) override;
+   FrameBuffer *frameBuffer(WId id, const QVariantMap &args) override;
 
 private:
    Q_DISABLE_COPY(PWFrameBufferPlugin)
