@@ -35,7 +35,7 @@ public:
     QtFrameBufferPlugin(QObject *parent, const QVariantList &args);
     ~QtFrameBufferPlugin() override;
 
-    FrameBuffer *frameBuffer(WId id) override;
+    FrameBuffer *frameBuffer(WId id, const QVariantMap &args) override;
 
 private:
     Q_DISABLE_COPY(QtFrameBufferPlugin)
